# 1D data products for CARMA EDGE

Currently includes:
* CO Rotation curves from Leung et al. (2018 MNRAS 477, 254).
* CO and Ha rotation curves from Levy et al. (2018 ApJ 860, 92).  The 6 arcsec curves were used in the paper.
* Radial CO profiles from native CO resolution smoothed-mask moment maps (TW unpublished).

Planned additions:
* CO and HI integrated spectra.
* Rotation curves from 3D Barolo.
